@@ -53,14 +53,43 @@ class FeiShuPlugin(NotificationPlugin):
         project = event.group.project
         title = event.title.encode("utf-8").decode("utf-8")
         project_name = project.get_full_name().encode("utf-8").decode("utf-8")
-        data = {"title": title, "msg_type": "text",
-                "content": {"text": "**Sentry Alters** \n**title**: {title} \nproject name: {project_name} \nmessage: {message}\n[点击详情]({url})".format(
-                    title=title,
-                    message=event.message,
-                    project_name=project_name,
-                    url=u"{}events/{}/".format(group.get_absolute_url(),
-                                               event.event_id),
-                )}}
+        device = event.get_tag('device')
+        level = group.get_level_display().upper()
+
+        data = {
+            "msg_type": "interactive",
+            "card": {
+                "header": {
+                    "title": {
+                        "content": "【Sentry Alert】 {project_name}".format(project_name=project_name),
+                        "tag": "plain_text"
+                    }
+                },
+                "elements": [
+                    {
+                        "tag": "div",
+                        "text": {
+                            "content": "**【TITLE】** {title}\n**【LEVEL】** {level}\n**【DEVICE】** {device}\n**【MESSAGE】** {message}\n".format(title=title, level=level, device=device, message=event.message),
+                            "tag": "lark_md"
+                        }
+                    },
+                    {
+                        "actions": [
+                            {
+                                "tag": "button",
+                                "text": {
+                                    "content": "查看详情",
+                                    "tag": "lark_md"
+                                },
+                                "url": u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
+                                "type": "normal"
+                            }
+                        ],
+                        "tag": "action"
+                    }
+                ],
+            }
+        }
         requests.post(
             send_url,
             json=data
